Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(108)

Unified Diff: runtime/vm/flow_graph_builder.h

Issue 1390153004: Move deopt_id and related helpers/definitions from Isolate to Thread (Closed) Base URL: https://github.com/dart-lang/sdk.git@master
Patch Set: Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: runtime/vm/flow_graph_builder.h
diff --git a/runtime/vm/flow_graph_builder.h b/runtime/vm/flow_graph_builder.h
index 7070e2ae9b2cb25eda2ee346db7125d61f067f1a..109a9a1c7e31e17126a407ebb8e9d86186339304 100644
--- a/runtime/vm/flow_graph_builder.h
+++ b/runtime/vm/flow_graph_builder.h
@@ -124,7 +124,7 @@ class InlineExitCollector: public ZoneAllocated {
class FlowGraphBuilder : public ValueObject {
public:
// The inlining context is NULL if not inlining. The osr_id is the deopt
// id of the OSR entry or Isolate::kNoDeoptId if not compiling for OSR.
FlowGraphBuilder(const ParsedFunction& parsed_function,
const ZoneGrowableArray<const ICData*>& ic_data_array,
InlineExitCollector* exit_collector,
@@ -210,6 +210,7 @@ class FlowGraphBuilder : public ValueObject {
// Returns address where the constant 'value' is stored or 0 if not found.
static uword FindDoubleConstant(double value);
+ Thread* thread() const { return parsed_function().thread(); }
Isolate* isolate() const { return parsed_function().isolate(); }
Zone* zone() const { return parsed_function().zone(); }
@@ -247,7 +248,7 @@ class FlowGraphBuilder : public ValueObject {
// A stack of enclosing nested statements.
NestedStatement* nesting_stack_;
// The deopt id of the OSR entry or Isolate::kNoDeoptId if not compiling
// for OSR.
const intptr_t osr_id_;
@@ -466,6 +467,7 @@ class EffectGraphVisitor : public AstNodeVisitor {
void BuildInstanceGetterConditional(InstanceGetterNode* node);
void BuildInstanceCallConditional(InstanceCallNode* node);
+ Thread* thread() const { return owner()->thread(); }
Isolate* isolate() const { return owner()->isolate(); }
Zone* zone() const { return owner()->zone(); }
@@ -124,7 +124,7 @@ class InlineExitCollector: public ZoneAllocated {
public:
// The inlining context is NULL if not inlining. The osr_id is the deopt
- // id of the OSR entry or Isolate::kNoDeoptId if not compiling for OSR.
+ // id of the OSR entry or Thread::kNoDeoptId if not compiling for OSR.
FlowGraphBuilder(const ParsedFunction& parsed_function,
const ZoneGrowableArray<const ICData*>& ic_data_array,
@@ -247,7 +248,7 @@ class FlowGraphBuilder : public ValueObject {
// A stack of enclosing nested statements.
NestedStatement* nesting_stack_;
- // The deopt id of the OSR entry or Isolate::kNoDeoptId if not compiling
+ // The deopt id of the OSR entry or Thread::kNoDeoptId if not compiling
// for OSR.
const intptr_t osr_id_;

Powered by Google App Engine
This is Rietveld 408576698